@@ -382,8 +382,7 @@ def update_ssh_config_entry(engine_name: str, instance_id: str, ssh_user: str):
 Host {engine_name} {SSH_MANAGED_COMMENT}
     HostName {instance_id}
     User {ssh_user}
-    ProxyCommand sh -c "aws ssm start-session --target %h --document-name AWS-StartSSHSession --idle-timeout 600 --parameters 'portNumber=%p'"
-"""
+    ProxyCommand sh -c \"AWS_SSM_IDLE_TIMEOUT=600 aws ssm start-session --target %h --document-name AWS-StartSSHSession --parameters 'portNumber=%p'\"\n"""
 
     # Check if entry already exists
     host_line = f"Host {engine_name} {SSH_MANAGED_COMMENT}"
@@ -617,7 +616,6 @@ def engine_status(
         f"[bold]Instance:[/bold]    {engine['instance_id']}",
         f"[bold]Type:[/bold]        {engine['engine_type']} ({engine['instance_type']})",
         f"[bold]Status:[/bold]      {format_status(engine['state'], engine.get('ready'))}",
-        f"[bold]Bootstrap:[/bold]   {_colour_stage(stage_val)}",
         f"[bold]User:[/bold]        {engine['user']}",
         f"[bold]IP:[/bold]          {engine.get('public_ip', 'N/A')}",
         f"[bold]Launched:[/bold]    {launch_time.strftime('%Y-%m-%d %H:%M:%S')} ({format_duration(uptime)} ago)",
@@ -945,7 +943,7 @@ def config_ssh(
                     f"Host {engine['name']} {SSH_MANAGED_COMMENT}",
                     f"    HostName {engine['instance_id']}",
                     f"    User {ssh_user}",
-                    f"    ProxyCommand sh -c \"aws ssm start-session --target %h --document-name AWS-StartSSHSession --idle-timeout 600 --parameters 'portNumber=%p'\"",
+                    f"    ProxyCommand sh -c \"AWS_SSM_IDLE_TIMEOUT=600 aws ssm start-session --target %h --document-name AWS-StartSSHSession --parameters 'portNumber=%p'\"",
                 ]
             )
 
